YARP 2.3.60 (2014-01-29)                                              {#v2_3_60}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.22...v2.3.60`):

```
   187	Paul Fitzpatrick <paulfitz@alum.mit.edu>
   124	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    93	Elena Ceseracciu <elena.ceseracciu@iit.it>
    22	Ali Paikan <ali.paikan@iit.it>
    22	Konstantinos Theofilis <kostas@ams.eng.osaka-u.ac.jp>
    18	Marco Randazzo <marco.randazzo@iit.it>
    13	Lorenzo Natale <lorenzo.natale@iit.it>
     9	Alberto Cardellino <alberto.cardellino@iit.it>
     9	Ugo Pattacini <ugo.pattacini@iit.it>
     8	Alessandro Scalzo <alessandro.scalzo@iit.it>
     3	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Enrico Mingo <enrico.mingo@iit.it>
     1	YARP Developers <yarp0-devel@lists.sourceforge.net>
```
